@@ -190,6 +190,7 @@ digest_calc_response (const char ha1[HASH_MD5_HEX_LEN + 1],
   unsigned char ha2[MD5_DIGEST_SIZE];
   unsigned char resphash[MD5_DIGEST_SIZE];
   char ha2hex[HASH_MD5_HEX_LEN + 1];
+  (void)hentity; /* Unused. Silent compiler warning. */
 
   MD5Init (&md5);
   MD5Update (&md5,
@@ -461,6 +462,7 @@ check_nonce_nc (struct MHD_Connection *connection,
  * @param connection The MHD connection structure
  * @return NULL if no username could be found, a pointer
  * 			to the username if found
+ * @warning Returned value must be freed by #MHD_free().
  * @ingroup authentication
  */
 char *
