@@ -85,6 +85,44 @@
 #  define MHD_THRD_CALL_SPEC_ __stdcall
 #endif
 
+#if defined(MHD_USE_POSIX_THREADS)
+  typedef pthread_t MHD_thread_ID_;
+#elif defined(MHD_USE_W32_THREADS)
+  typedef DWORD MHD_thread_ID_;
+#endif
+
+/* Depending on implementation, pthread_create() MAY set thread ID into
+ * provided pointer and after it start thread OR start thread and after
+ * if set thread ID. In latter case, to avoid data races, additional
+ * pthread_self() call is required in thread routine. Is some platform
+ * is known for setting thread ID BEFORE starting thread macro
+ * MHD_PTHREAD_CREATE__SET_ID_BEFORE_START_THREAD could be defined
+ * to save some resources. */
+#if defined(MHD_USE_POSIX_THREADS)
+#  ifdef MHD_PTHREAD_CREATE__SET_ID_BEFORE_START_THREAD
+  union _MHD_thread_handle_ID_
+  {
+    MHD_thread_handle_  handle; /**< To be used in other threads */
+    MHD_thread_ID_      ID;     /**< To be used in thread itself */
+  };
+  typedef union _MHD_thread_handle_ID_ MHD_thread_handle_ID_;
+#  else  /* ! MHD_PTHREAD_CREATE__SET_ID_BEFORE_START_THREAD */
+  struct _MHD_thread_handle_ID_
+  {
+    MHD_thread_handle_  handle; /**< To be used in other threads */
+    MHD_thread_ID_      ID;     /**< To be used in thread itself */
+  };
+  typedef struct _MHD_thread_handle_ID_ MHD_thread_handle_ID_;
+#  endif /* ! MHD_PTHREAD_CREATE__SET_ID_BEFORE_START_THREAD */
+#elif defined(MHD_USE_W32_THREADS)
+  struct _MHD_thread_handle_ID_
+  {
+    MHD_thread_handle_  handle; /**< To be used in other threads */
+    MHD_thread_ID_      ID;     /**< To be used in thread itself */
+  };
+  typedef struct _MHD_thread_handle_ID_ MHD_thread_handle_ID_;
+#endif
+
 #if defined(MHD_USE_POSIX_THREADS)
 /**
  * Wait until specified thread is ended and free thread handle on success.
@@ -101,6 +139,44 @@
 #define MHD_join_thread_(thread) (WAIT_OBJECT_0 == WaitForSingleObject((thread), INFINITE) ? (CloseHandle((thread)), !0) : 0)
 #endif
 
+#if defined(MHD_USE_POSIX_THREADS)
+/**
+ * Check whether provided thread ID match current thread.
+ * @param ID thread ID to match
+ * @return nonzero on match, zero otherwise
+ */
+#define MHD_thread_ID_match_current_(ID) (pthread_equal((ID), pthread_self()))
+#elif defined(MHD_USE_W32_THREADS)
+/**
+ * Check whether provided thread ID match current thread.
+ * @param ID thread ID to match
+ * @return nonzero on match, zero otherwise
+ */
+#define MHD_thread_ID_match_current_(ID) (GetCurrentThreadId() == (ID))
+#endif
+
+#if defined(MHD_USE_POSIX_THREADS)
+#  ifdef MHD_PTHREAD_CREATE__SET_ID_BEFORE_START_THREAD
+/**
+ * Initialise thread ID.
+ * @param thread_handle_ID_ptr pointer to thread handle-ID
+ */
+#define MHD_thread_init_(thread_handle_ID_ptr) (void)0
+#  else  /* ! MHD_PTHREAD_CREATE__SET_ID_BEFORE_START_THREAD */
+/**
+ * Initialise thread ID.
+ * @param thread_handle_ID_ptr pointer to thread handle-ID
+ */
+#define MHD_thread_init_(thread_handle_ID_ptr) ((thread_handle_ID_ptr)->ID=pthread_self())
+#  endif /* ! MHD_PTHREAD_CREATE__SET_ID_BEFORE_START_THREAD */
+#elif defined(MHD_USE_W32_THREADS)
+/**
+ * Initialise thread ID.
+ * @param thread_handle_ID_ptr pointer to thread handle-ID
+ */
+#define MHD_thread_init_(thread_handle_ID_ptr) ((thread_handle_ID_ptr)->ID=GetCurrentThreadId())
+#endif
+
 /**
  * Signature of main function for a thread.
  *
@@ -123,7 +199,7 @@ typedef MHD_THRD_RTRN_TYPE_
  * @return non-zero on success; zero otherwise
  */
 int
-MHD_create_thread_ (MHD_thread_handle_ *thread,
+MHD_create_thread_ (MHD_thread_handle_ID_ *thread,
                     size_t stack_size,
                     MHD_THREAD_START_ROUTINE_ start_routine,
                     void *arg);
@@ -142,7 +218,7 @@ MHD_create_thread_ (MHD_thread_handle_ *thread,
  * @return non-zero on success; zero otherwise
  */
 int
-MHD_create_named_thread_ (MHD_thread_handle_ *thread,
+MHD_create_named_thread_ (MHD_thread_handle_ID_ *thread,
                           const char* thread_name,
                           size_t stack_size,
                           MHD_THREAD_START_ROUTINE_ start_routine,
